==> open-xchange-usm_7.0.1.orig.tar.bz2: open-xchange-usm-7.0.1/com.openexchange.usm.database.ox/src/com/openexchange/usm/database/ox/USMTablesUpdateTask.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.usm.database.ox;

import java.sql.Connection;
import java.sql.SQLException;
import com.openexchange.exception.OXException;
import com.openexchange.groupware.update.PerformParameters;
import com.openexchange.groupware.update.Schema;
import com.openexchange.usm.api.database.DatabaseAccessException;
import com.openexchange.usm.api.exceptions.USMSQLException;

public class USMTablesUpdateTask extends USMBaseUpdateTask {

	public USMTablesUpdateTask(USMUpdateTaskProvider updateTaskProvider) {
		super(updateTaskProvider);
	}

	public int addedWithVersion() {
		return 37;
	}

	public void doPerform(PerformParameters parameters) throws OXException {
		doPerform(parameters.getSchema(), parameters.getContextId());
	}

	@Override
	protected void doPerform(Schema schema, int contextId) throws OXException {
		for (int i = 0; i < TableDefinition.TABLE_NAMES.length; i++)
			createTable(TableDefinition.TABLE_NAMES[i], TableDefinition.SQL_STATEMENTS[i], contextId);

		for (int i = 0; i < TableDefinition.SEQUENCE_TABLES_NAMES.length; i++) {
			Connection con = null;
			try {
				con = _provider.getDatabaseService().getWritable(contextId);
				String tablename = TableDefinition.SEQUENCE_TABLES_NAMES[i];
				TableDefinition.generateSequence(tablename, con, _provider.getJournal(), true, !tableExists(tablename,
						con.getMetaData()));
			} catch (SQLException e) {
				throw USMUpdateExceptionCodes.SQL_ERROR.create(e);
			} catch (USMSQLException e) {
				throw USMUpdateExceptionCodes.SQL_ERROR.create(e);
			} catch (DatabaseAccessException e) {
				throw USMUpdateExceptionCodes.SQL_ERROR.create(e);
			} finally {
				if (con != null)
					_provider.getDatabaseService().backWritable(contextId, con);
			}
		}
	}
}

==> open-xchange-usm_7.4.0.orig.tar.bz2: open-xchange-usm-7.4.0/com.openexchange.usm.database.ox/src/com/openexchange/usm/database/ox/USMTablesUpdateTask.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.usm.database.ox;

import java.sql.Connection;
import java.sql.SQLException;
import com.openexchange.exception.OXException;
import com.openexchange.groupware.update.PerformParameters;
import com.openexchange.groupware.update.Schema;
import com.openexchange.usm.api.database.DatabaseAccessException;
import com.openexchange.usm.api.exceptions.USMSQLException;

public class USMTablesUpdateTask extends USMBaseUpdateTask {

	public USMTablesUpdateTask(USMUpdateTaskProvider updateTaskProvider) {
		super(updateTaskProvider);
	}

	public int addedWithVersion() {
		return 37;
	}

	public void doPerform(PerformParameters parameters) throws OXException {
		doPerform(parameters.getSchema(), parameters.getContextId());
	}

	@Override
	protected void doPerform(Schema schema, int contextId) throws OXException {
		for (int i = 0; i < TableDefinition.TABLE_NAMES.length; i++)
			createTable(TableDefinition.TABLE_NAMES[i], TableDefinition.SQL_STATEMENTS[i], contextId);

		for (int i = 0; i < TableDefinition.SEQUENCE_TABLES_NAMES.length; i++) {
			Connection con = null;
			try {
				con = _provider.getDatabaseService().getForUpdateTask(contextId);
				String tablename = TableDefinition.SEQUENCE_TABLES_NAMES[i];
				TableDefinition.generateSequence(tablename, con, _provider.getJournal(), true, !tableExists(tablename,
						con.getMetaData()));
			} catch (SQLException e) {
				throw USMUpdateExceptionCodes.SQL_ERROR.create(e);
			} catch (USMSQLException e) {
				throw USMUpdateExceptionCodes.SQL_ERROR.create(e);
			} catch (DatabaseAccessException e) {
				throw USMUpdateExceptionCodes.SQL_ERROR.create(e);
			} finally {
				if (con != null)
					_provider.getDatabaseService().backWritable(contextId, con);
			}
		}
	}
}
